﻿namespace Brizco.Api.Controllers;

public class ActivityController : ICarterModule
{
    public void AddRoutes(IEndpointRouteBuilder app)
    {

        var group = app.NewVersionedApi("Activity")
            .MapGroup($"api/activity")
            .RequireAuthorization(builder => builder.AddAuthenticationSchemes("Bearer").RequireAuthenticatedUser());

        group.MapGet("", GetAllAsync)
            .WithDisplayName("GetActivities")
            .HasApiVersion(1.0);

        group.MapGet("{id:guid}", GetAsync)
            .WithDisplayName("GetActivity")
            .HasApiVersion(1.0);

        group.MapGet("done/{id:guid}", DoneActivityAsync)
            .WithDisplayName("DoneActivity")
            .HasApiVersion(1.0);

        //group.MapPost("", Post)
        //    .AllowAnonymous()
        //    .HasApiVersion(1.0);

        //group.MapPut("", Put)
        //    .HasApiVersion(1.0);

        //group.MapDelete("{id:guid}", Delete)
        //    .HasApiVersion(1.0);

    }


    // GET:Get All Entity
    public async Task<IResult> GetAllAsync([FromQuery] int page, ISender sender, CancellationToken cancellationToken)
        => TypedResults.Ok(await sender.Send(new GetActivitiesQuery(page), cancellationToken));

    // GET:Get An Entity By Id
    public async Task<IResult> GetAsync(Guid id, IActivityService activityService, CancellationToken cancellationToken)
        => TypedResults.Ok(await activityService.DoneActivityAsync(id,cancellationToken));

    public async Task<IResult> DoneActivityAsync(Guid id, ISender sender, CancellationToken cancellationToken)
        => TypedResults.Ok(await sender.Send(new GetActivityQuery(id), cancellationToken));

    //// POST:Create Entity
    //public async Task<IResult> Post([FromQuery]Guid shiftPlanId,IActivityService activityService, CancellationToken cancellationToken)
    //    => TypedResults.Ok(await activityService.CreateActivitiesByShiftPlan(shiftPlanId,cancellationToken));

    //// PUT:Update Entity
    //public async Task<IResult> Put([FromBody] UpdateActivityCommand ent, ISender mediator, CancellationToken cancellationToken)
    //    => TypedResults.Ok(await mediator.Send(ent, cancellationToken));

    //// DELETE:Delete Entity
    //public async Task<IResult> Delete(Guid id, ISender mediator, CancellationToken cancellationToken)
    //    => TypedResults.Ok(await mediator.Send(new DeleteActivityCommand(id), cancellationToken));
}