﻿namespace Brizco.Api.Controllers;

public class SectionController : ICarterModule
{

    public virtual void AddRoutes(IEndpointRouteBuilder app)
    {
        var group = app.NewVersionedApi("Section")
            .MapGroup($"api/section")
            .RequireAuthorization(builder => builder.AddAuthenticationSchemes("Bearer").RequireAuthenticatedUser());

        group.MapGet("", GetAllAsync)
            .WithDisplayName("GetAllSections")
            .HasApiVersion(1.0);

        group.MapGet("{id}", GetAsync)
            .WithDisplayName("GetSection")
            .HasApiVersion(1.0);

        group.MapPost("", Post)
            .HasApiVersion(1.0);

        group.MapPut("", Put)
            .HasApiVersion(1.0);

        group.MapDelete("{id}", Delete)
            .HasApiVersion(1.0);
    }

    // GET:Get All Entity
    public async Task<IResult> GetAllAsync([FromQuery] int page, ISender sender, CancellationToken cancellationToken)
        => TypedResults.Ok(await sender.Send(new GetSectionsQuery(page), cancellationToken));

    // GET:Get An Entity By Id
    public async Task<IResult> GetAsync(Guid id, ISender sender, CancellationToken cancellationToken)
        => TypedResults.Ok(await sender.Send(new GetSectionQuery(id), cancellationToken));

    // POST:Create Entity
    public async Task<IResult> Post([FromBody] CreateSectionCommand ent, ISender mediator, CancellationToken cancellationToken)
        => TypedResults.Ok(await mediator.Send(ent, cancellationToken));

    // PUT:Update Entity
    public async Task<IResult> Put([FromBody] UpdateSectionCommand ent, ISender mediator, CancellationToken cancellationToken)
        => TypedResults.Ok(await mediator.Send(ent, cancellationToken));

    // DELETE:Delete Entity
    public async Task<IResult> Delete(Guid id, ISender mediator, CancellationToken cancellationToken)
        => TypedResults.Ok(await mediator.Send(new DeleteSectionCommand(id), cancellationToken));

}