﻿namespace Brizco.Api.Controllers;

public class ShiftPlanController : ICarterModule
{
    public void AddRoutes(IEndpointRouteBuilder app)
    {

        var group = app.NewVersionedApi("ShiftPlan")
            .MapGroup($"api/shift/plan")
            .RequireAuthorization(builder => builder.AddAuthenticationSchemes("Bearer").RequireAuthenticatedUser());

        group.MapGet("", GetAllAsync)
            .WithDisplayName("GetShiftPlans")
            .HasApiVersion(1.0);

        group.MapGet("{id:guid}", GetAsync)
            .WithDisplayName("GetShiftPlan")
            .HasApiVersion(1.0);

        group.MapPost("", Post)
            .HasApiVersion(1.0);

        group.MapPut("", Put)
            .HasApiVersion(1.0);

        group.MapDelete("{id:guid}", Delete)
        .HasApiVersion(1.0);

    }


    // GET:Get All Entity
    public async Task<IResult> GetAllAsync([FromQuery] int page, ISender sender, CancellationToken cancellationToken)
        => TypedResults.Ok(await sender.Send(new GetShiftPlansQuery(page), cancellationToken));

    // GET:Get An Entity By Id
    public async Task<IResult> GetAsync(Guid id, ISender sender, CancellationToken cancellationToken)
        => TypedResults.Ok(await sender.Send(new GetShiftPlanQuery(id),cancellationToken));

    // POST:Create Entity
    public async Task<IResult> Post([FromBody] CreateShiftPlanCommand ent, IShiftPlanService shiftPlanService, CancellationToken cancellationToken)
        => TypedResults.Ok(await shiftPlanService.CreateAsync(ent, cancellationToken));

    // PUT:Update Entity
    public async Task<IResult> Put([FromBody] UpdateShiftPlanCommand ent, ISender mediator, CancellationToken cancellationToken)
        => TypedResults.Ok(await mediator.Send(ent, cancellationToken));

    // DELETE:Delete Entity
    public async Task<IResult> Delete(Guid id, ISender mediator, CancellationToken cancellationToken)
        => TypedResults.Ok(await mediator.Send(new DeleteShiftPlanCommand(id), cancellationToken));
}